import * as tslib_1 from "tslib";
import { validate } from "@hpcc-js/ddl";
import { Table } from "@hpcc-js/dgrid";
import { JSXWidget, VizInstance } from "@hpcc-js/html";
import { JSONEditor } from "./JSONEditor";
import "../src/DDLEditor.css";
var DDLEditor = (function (_super) {
    tslib_1.__extends(DDLEditor, _super);
    function DDLEditor() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.summary = "0 Errors";
        _this._ddlEditor = new JSONEditor().on("changes", function (changes) {
            _this.checkSyntax();
        });
        _this._errorTable = new Table()
            .columns(["dataPath", "keyword", "message", "params"]);
        _this.jsx = JSXWidget.createElement("div", null,
            JSXWidget.createElement(VizInstance, { instance: _this._ddlEditor }),
            JSXWidget.createElement(VizInstance, { instance: _this._errorTable }));
        return _this;
    }
    DDLEditor.prototype.ddl = function (_) {
        if (!arguments.length)
            return this._ddlEditor.json();
        this._ddlEditor.json(_);
        this.checkSyntax();
        return this;
    };
    DDLEditor.prototype.checkSyntax = function () {
        try {
            var json = this.ddl();
            try {
                var d = validate(json);
                if (d.success) {
                    this._errorTable.data([]);
                }
                else {
                    this._errorTable.data(d.errors.map(function (error) { return [error.dataPath, error.keyword, error.message, JSON.stringify(error.params)]; }));
                }
            }
            catch (e) {
                this._errorTable.data([["", "Validation Failed", "", ""]]);
            }
        }
        catch (e) {
            this._errorTable.data([["", "Invalid JSON", "", ""]]);
        }
        if (this._renderCount) {
            this._errorTable.lazyRender();
        }
    };
    DDLEditor.prototype.enter = function (domNode, element) {
        _super.prototype.enter.call(this, domNode, element);
    };
    DDLEditor.prototype.update = function (domNode, _element) {
        _super.prototype.update.call(this, domNode, _element);
        this._ddlEditor.size({ width: this.width(), height: this.height() * 6 / 9 });
        this._errorTable.size({ width: this.width(), height: this.height() * 3 / 9 });
        this.jsxRender(this.jsx, domNode);
    };
    return DDLEditor;
}(JSXWidget));
export { DDLEditor };
DDLEditor.prototype._class += " codemirror_DDLEditor";
//# sourceMappingURL=DDLEditor.js.map