(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "tslib", "@hpcc-js/ddl", "@hpcc-js/dgrid", "@hpcc-js/html", "./JSONEditor", "../src/DDLEditor.css"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require("tslib");
    var ddl_1 = require("@hpcc-js/ddl");
    var dgrid_1 = require("@hpcc-js/dgrid");
    var html_1 = require("@hpcc-js/html");
    var JSONEditor_1 = require("./JSONEditor");
    require("../src/DDLEditor.css");
    var DDLEditor = (function (_super) {
        tslib_1.__extends(DDLEditor, _super);
        function DDLEditor() {
            var _this = _super !== null && _super.apply(this, arguments) || this;
            _this.summary = "0 Errors";
            _this._ddlEditor = new JSONEditor_1.JSONEditor().on("changes", function (changes) {
                _this.checkSyntax();
            });
            _this._errorTable = new dgrid_1.Table()
                .columns(["dataPath", "keyword", "message", "params"]);
            _this.jsx = html_1.JSXWidget.createElement("div", null,
                html_1.JSXWidget.createElement(html_1.VizInstance, { instance: _this._ddlEditor }),
                html_1.JSXWidget.createElement(html_1.VizInstance, { instance: _this._errorTable }));
            return _this;
        }
        DDLEditor.prototype.ddl = function (_) {
            if (!arguments.length)
                return this._ddlEditor.json();
            this._ddlEditor.json(_);
            this.checkSyntax();
            return this;
        };
        DDLEditor.prototype.checkSyntax = function () {
            try {
                var json = this.ddl();
                try {
                    var d = ddl_1.validate(json);
                    if (d.success) {
                        this._errorTable.data([]);
                    }
                    else {
                        this._errorTable.data(d.errors.map(function (error) { return [error.dataPath, error.keyword, error.message, JSON.stringify(error.params)]; }));
                    }
                }
                catch (e) {
                    this._errorTable.data([["", "Validation Failed", "", ""]]);
                }
            }
            catch (e) {
                this._errorTable.data([["", "Invalid JSON", "", ""]]);
            }
            if (this._renderCount) {
                this._errorTable.lazyRender();
            }
        };
        DDLEditor.prototype.enter = function (domNode, element) {
            _super.prototype.enter.call(this, domNode, element);
        };
        DDLEditor.prototype.update = function (domNode, _element) {
            _super.prototype.update.call(this, domNode, _element);
            this._ddlEditor.size({ width: this.width(), height: this.height() * 6 / 9 });
            this._errorTable.size({ width: this.width(), height: this.height() * 3 / 9 });
            this.jsxRender(this.jsx, domNode);
        };
        return DDLEditor;
    }(html_1.JSXWidget));
    exports.DDLEditor = DDLEditor;
    DDLEditor.prototype._class += " codemirror_DDLEditor";
});
//# sourceMappingURL=DDLEditor.js.map